Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(427)

Unified Diff: runtime/vm/object.h

Issue 1287463003: Refactor skipped code functions interface. (Closed) Base URL: git@github.com:dart-lang/sdk.git@master
Patch Set: rm garbage file. Created 5 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/vm/gc_marker.cc ('k') | runtime/vm/raw_object.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/object.h
diff --git a/runtime/vm/object.h b/runtime/vm/object.h
index 3c1ec51eb1bb4ded7efa60df0c8f4cfa7c24a979..52b16c2dcf4320f6bfc803223073e34ff11f81f7 100644
--- a/runtime/vm/object.h
+++ b/runtime/vm/object.h
@@ -6168,8 +6168,8 @@ class String : public Instance {
friend class TwoByteString;
friend class ExternalOneByteString;
friend class ExternalTwoByteString;
- // So that the MarkingVisitor can print a debug string from a NoHandleScope.
- friend class MarkingVisitor;
+ // So that SkippedCodeFunctions can print a debug string from a NoHandleScope.
+ friend class SkippedCodeFunctions;
};
« no previous file with comments | « runtime/vm/gc_marker.cc ('k') | runtime/vm/raw_object.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698